Exception: Gemvault::Timestamp::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Gemvault::Timestamp::Error
- Defined in:
- lib/gemvault/timestamp.rb
Overview
Raised when a value is in no notation a vault can store.
Raised when a value is in no notation a vault can store.