Exception: Gemvault::VaultDestination::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Gemvault::VaultDestination::Error
- Defined in:
- lib/gemvault/vault_destination.rb
Overview
Raised when the path cannot hold a new vault.
Raised when the path cannot hold a new vault.